==> 5.8.0.tar.gz: ciphey/translations/ru/CONTRIBUTING.md <==
Здорово!

Значит, вы заинтересованы в том, чтобы внести свой вклад в Ciphey? 🤔

Может быть, ты не совсем уверен, с чего начать. Или, может быть, вы считаете, что ваши навыки программирования "недостаточно хороши". Что касается последнего - полная чушь! Мы совсем не против "плохого кода". Кроме того, то, что вы читаете этот документ, говорит о том, что вы отличный программист. Ведь в проектах GitHub участвует очень мало новичков. 😉.

Вот несколько способов, которыми вы можете внести свой вклад:

Добавить новый язык 🧏
Разработайте новый метод декодирования, который до сих пор отсутствует. 📚 список смотрите здесь
Создавайте больше документации (очень wichtig‼️ Мы будем бесконечно благодарны).
Исправляйте ошибки, присылаемые в GitHub Issues (мы можем помочь вам с этим 😊).
Рефакторинг нашей кодовой базы 🥺.
Если все это звучит немного тяжеловато, не волнуйся! Этот документ поможет вам шаг за шагом к успеху. Также.... Ваше имя будет добавлено в список участников Ciphey! И последнее, но не менее важное: мы вам очень благодарны! 🙏

У нас есть сервер дискорда, где вы можете связаться с разработчиками и получить помощь. Кроме того, вы можете открыть выпуск GitHub с вашим предложением.

Сервер Раздора

Как я могу внести свой вклад?
Ciphey всегда нуждается в новых модулях расшифровки! Чтобы узнать, как можно интегрировать свой код в Ciphey, посмотрите здесь:

https://github.com/Ciphey/Ciphey/wiki/Adding-your-own-ciphers для простых инструкций.
https://github.com/Ciphey/Ciphey/wiki/Extending-Ciphey для ссылки на API.
Было бы здорово, если бы вы могли написать несколько тестов для своего кода. Это очень просто: скопируйте вашу функцию в Ciphey/tests/test_main.py и замените шифрованный текст чем-нибудь зашифрованным вашим методом. Скорее всего, мы также будем сливать код без тестов, но это сложнее отлаживать.

Конечно же, мы будем благодарны вам за вашу усердную работу в списке участников!

Добавить новый язык 🧏
Брендон определения языка по умолчанию работает с несколькими языками. Несмотря на то, что это может показаться немного сложным, добавить язык очень легко: Все, что вам нужно, это словарь языка, который вы анализируете с помощью одного из наших инструментов. Затем вы добавляете словарь и анализ в наш репозиторий. Наконец, добавьте опцию языка в settings.yml.

Создать документацию
Документация является наиболее важной частью Ciphey. Отсутствие документации - это огромный технический сбой, которого мы, конечно же, хотим избежать.

Одно можно сказать наверняка: если вы предоставите хорошую документацию, вы будете оценены так же, как и все, кто предоставляет хороший код! Документирование кода абсолютно необходимо для выживания любого проекта.

Существует множество способов предоставления документации:

Строки непосредственно в коде
Улучшение существующей документации (README, файл взноса, наши страницы чтения документов, ...).
Перевод документации
И многое другое!

Исправлять ошибки
Загляните в раздел "Проблемы с GitHub", чтобы узнать, какие ошибки есть на сайте в настоящее время. Если вы исправите ошибки, вы, конечно же, будете добавлены в список участников ;-)

Рефакторинг кодовой базы
PEP8 не придерживается всего нашего кода - и многие части кода существуют дважды.

==> 5.10.0.tar.gz: ciphey/translations/ru/CONTRIBUTING.md <==
Здорово!

Значит, вы заинтересованы в том, чтобы внести свой вклад в Ciphey? 🤔

Может быть, ты не совсем уверен, с чего начать. Или, может быть, вы считаете, что ваши навыки программирования "недостаточно хороши". Что касается последнего - полная чушь! Мы совсем не против "плохого кода". Кроме того, то, что вы читаете этот документ, говорит о том, что вы отличный программист. Ведь в проектах GitHub участвует очень мало новичков. 😉.

Вот несколько способов, которыми вы можете внести свой вклад:

Добавить новый язык 🧏
Разработайте новый метод декодирования, который до сих пор отсутствует. 📚 список смотрите здесь
Создавайте больше документации (очень wichtig‼️ Мы будем бесконечно благодарны).
Исправляйте ошибки, присылаемые в GitHub Issues (мы можем помочь вам с этим 😊).
Рефакторинг нашей кодовой базы 🥺.
Если все это звучит немного тяжеловато, не волнуйся! Этот документ поможет вам шаг за шагом к успеху. Также.... Ваше имя будет добавлено в список участников Ciphey! И последнее, но не менее важное: мы вам очень благодарны! 🙏

У нас есть сервер дискорда, где вы можете связаться с разработчиками и получить помощь. Кроме того, вы можете открыть выпуск GitHub с вашим предложением.

Сервер Раздора

Как я могу внести свой вклад?
Ciphey всегда нуждается в новых модулях расшифровки! Чтобы узнать, как можно интегрировать свой код в Ciphey, посмотрите здесь:

<https://github.com/Ciphey/Ciphey/wiki/Adding-your-own-ciphers> для простых инструкций.
<https://github.com/Ciphey/Ciphey/wiki/Extending-Ciphey> для ссылки на API.
Было бы здорово, если бы вы могли написать несколько тестов для своего кода. Это очень просто: скопируйте вашу функцию в Ciphey/tests/test_main.py и замените шифрованный текст чем-нибудь зашифрованным вашим методом. Скорее всего, мы также будем сливать код без тестов, но это сложнее отлаживать.

Конечно же, мы будем благодарны вам за вашу усердную работу в списке участников!

Добавить новый язык 🧏
Брендон определения языка по умолчанию работает с несколькими языками. Несмотря на то, что это может показаться немного сложным, добавить язык очень легко: Все, что вам нужно, это словарь языка, который вы анализируете с помощью одного из наших инструментов. Затем вы добавляете словарь и анализ в наш репозиторий. Наконец, добавьте опцию языка в settings.yml.

Создать документацию
Документация является наиболее важной частью Ciphey. Отсутствие документации - это огромный технический сбой, которого мы, конечно же, хотим избежать.

Одно можно сказать наверняка: если вы предоставите хорошую документацию, вы будете оценены так же, как и все, кто предоставляет хороший код! Документирование кода абсолютно необходимо для выживания любого проекта.

Существует множество способов предоставления документации:

Строки непосредственно в коде
Улучшение существующей документации (README, файл взноса, наши страницы чтения документов, ...).
Перевод документации
И многое другое!

Исправлять ошибки
Загляните в раздел "Проблемы с GitHub", чтобы узнать, какие ошибки есть на сайте в настоящее время. Если вы исправите ошибки, вы, конечно же, будете добавлены в список участников ;-)

Рефакторинг кодовой базы
PEP8 не придерживается всего нашего кода - и многие части кода существуют дважды.
